@@ -4,8 +4,8 @@
 
 #include <glib-object.h>
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-certificate-chain.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-certificate-chain.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-certificate-chain.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-certificate-chain.h" */
 GType gcr_certificate_chain_status_get_type (void) G_GNUC_CONST;
 
 GType
@@ -44,8 +44,8 @@ gcr_certificate_chain_flags_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-certificate-request.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-certificate-request.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-certificate-request.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-certificate-request.h" */
 GType gcr_certificate_request_format_get_type (void) G_GNUC_CONST;
 
 GType
@@ -62,8 +62,8 @@ gcr_certificate_request_format_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-column.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-column.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-column.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-column.h" */
 GType gcr_column_flags_get_type (void) G_GNUC_CONST;
 
 GType
@@ -82,8 +82,8 @@ gcr_column_flags_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-deprecated-base.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-deprecated-base.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-deprecated-base.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-deprecated-base.h" */
 GType gcr_importer_prompt_behavior_get_type (void) G_GNUC_CONST;
 
 GType
@@ -102,8 +102,8 @@ gcr_importer_prompt_behavior_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-prompt.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-prompt.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-prompt.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-prompt.h" */
 GType gcr_prompt_reply_get_type (void) G_GNUC_CONST;
 
 GType
@@ -121,8 +121,8 @@ gcr_prompt_reply_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-system-prompt.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-system-prompt.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-system-prompt.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-system-prompt.h" */
 GType gcr_system_prompt_error_get_type (void) G_GNUC_CONST;
 
 GType
@@ -139,8 +139,8 @@ gcr_system_prompt_error_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-system-prompter.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-system-prompter.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-system-prompter.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-system-prompter.h" */
 GType gcr_system_prompter_mode_get_type (void) G_GNUC_CONST;
 
 GType
@@ -158,8 +158,8 @@ gcr_system_prompter_mode_get_type (void)
     return etype;
 }
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-types.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.x86_64/src/gcr-3.18.0/gcr/gcr-types.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-types.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.i686/src/gcr-3.20.0/gcr/gcr-types.h" */
 GType gcr_data_error_get_type (void) G_GNUC_CONST;
 
 GType
