@@ -4,8 +4,8 @@
 
 #include <glib-object.h>
 
-#include "/usr/src/ports/gcr/gcr-3.18.0-1.i686/src/gcr-3.18.0/ui/gcr-collection-model.h"
-/* enumerations from "/usr/src/ports/gcr/gcr-3.18.0-1.i686/src/gcr-3.18.0/ui/gcr-collection-model.h" */
+#include "/usr/src/ports/gcr/gcr-3.20.0-1.x86_64/src/gcr-3.20.0/ui/gcr-collection-model.h"
+/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.x86_64/src/gcr-3.20.0/ui/gcr-collection-model.h" */
 GType gcr_collection_model_mode_get_type (void) G_GNUC_CONST;
 
 GType
